#
# spec file for package container-suseconnect
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global project     container-suseconnect
%global import_path github.com/SUSE/%{project}
%global zypp_path   %{_prefix}/lib/zypp/plugins
%global zypp_services %{zypp_path}/services
%global zypp_urlresolver %{zypp_path}/urlresolver
Name:           %{project}
Version:        2.5.4
Release:        1.1
Summary:        Provides access to repositories inside containers
License:        Apache-2.0
Group:          Development/Languages/Other
URL:            https://%{import_path}
Source0:        %{project}-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        container-suseconnect-rpmlintrc
BuildRequires:  libzypp > 9.34
BuildRequires:  zstd
%if 0%{?suse_version} == 1500
BuildRequires:  go1.24-openssl
%else
BuildRequires:  golang(API) = 1.24
%endif
Requires:       libzypp > 9.34

%description
container-suseconnect gives access to package repositories inside containers
using the host machine entitlements.

%prep
%if 0%{?suse_version} && 0%{?suse_version} < 1500
export TAR_OPTIONS="-I zstd"
%endif
%setup -q -n %{project}-%{version} -a1

%build
%if 0%{?suse_version} > 1600
export GOFIPS140=v1.0.0
%endif
go build -tags enablecgo -o %{project} -mod=vendor -buildmode=pie -trimpath -ldflags="-s -w" ./cmd/container-suseconnect

%check
%if 0%{?suse_version} > 1600
export GODEBUG=fips140=only GOFIPS140=v1.0.0
%endif
go test ./...

%install
install -D -m 755 %{project} %{buildroot}/%{_bindir}/%{project}
mkdir -p %{buildroot}/%{zypp_services}
mkdir -p %{buildroot}/%{zypp_urlresolver}
ln -s %{_bindir}/%{project} %{buildroot}/%{zypp_services}/%{project}-zypp
ln -s %{_bindir}/%{project} %{buildroot}/%{zypp_urlresolver}/susecloud

%files
%doc README.md
%license LICENSE
%{_bindir}/%{project}
%{zypp_services}/%{project}-zypp
%{zypp_urlresolver}/susecloud

%changelog
* Tue Jun 10 2025 Dirk Müller <dmueller@suse.com>
- Update to version 2.5.4:
  * Switch to sha256 from md5
- use go's native fips module on tumbleweed
* Tue May 20 2025 Dirk Müller <dmueller@suse.com>
- Update to version 2.5.3 (bsc#1243360):
  * only handle command line options for the default arg0 case
  * parse and ignore the previously removed log-credentials-errors
  * Restore usage output on unhandled command line options
* Tue May 20 2025 alexandre.vicenzi@suse.com
- Update to version 2.5.2:
  * Prepare for new release
  * Fix default behavior
  * Use comma-separated lists for case in switch
  * Switch to go stable and update mod to 1.24.0
  * Remove use of urfave/cli and replace it with flag
  * Various golangci-lint v2.1x warnings fixed
  * Bump github.com/urfave/cli/v2 from 2.27.5 to 2.27.6
  * Also allow optionally to pass down the system_token
  * Bump github.com/stretchr/testify from 1.9.0 to 1.10.0
* Wed Apr 23 2025 Dirk Müller <dmueller@suse.com>
- update to 2.5.1:
  * Bump github.com/mssola/capture from 1.0.0 to 1.1.0
  * Log everything to stderr
  * Code formatting
  * Bump github.com/stretchr/testify from 1.9.0 to 1.10.0
  * Also allow optionally to pass down the system_token
  * Various golangci-lint v2.1x warnings fixed
  * Remove use of urfave/cli and replace it with flag
* Tue Mar  5 2024 Dirk Müller <dmueller@suse.com>
- remove unnecessary packaging buildrequires
* Wed Feb 28 2024 Dirk Müller <dmueller@suse.com>
- update to 2.5.0:
  * Upgrade to go 1.21
  * Allow setting of SCC credentials via environment variables
  * Bump github.com/urfave/cli/v2 from 2.25.7 to 2.27.1
  * Use switch instead of else if construction
  * Add system token header to query SCC subscriptions
    (bsc#1219855)
- run tests
* Thu Oct  5 2023 Dirk Müller <dmueller@suse.com>
- spec file cleanups
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to 2.4.0 (jsc#PED-1710):
  * Fix docker build example for non-SLE hosts
  * Minor fixes to --help and README
  * Improve documentation when building with podman on non-SLE host
  * Add flag --log-credentials-errors
  * Add GitHub actions
  * Remove vendor/ dir
  * Cleanup tests
  * Update capture to the 1.0.0 release
  * Bump cli to 2.34.4
  * Update cli to 2.23.5
  * Add dependabot
  * Use URL.Redacted() to avoid security scanner warning
  * Regcode fix
* Sat Mar 27 2021 Dirk Müller <dmueller@suse.com>
- strip binaries (removes 4MB/25%% of the uncompressed size) (bsc#1186827)
* Tue Jun 30 2020 Ralf Haferkamp <rhafer@suse.com>
- Update to 2.3.0 (bsc#1173375)
  - Introduce "containerbuild-regionsrv" support and add
    "susecloud" zypper url-resolver plugin to allow building SLE
    containers on public cloud on-demand instances
  - Fix usage with RMT when repositories require authentication
- remove "%%gosrc" call to avoid including all the go sources into
  the main package.
* Thu Nov 28 2019 Ralf Haferkamp <rhafer@suse.com>
- Update to 2.2.0 (bsc#1157960)
  - Update go version and dependencies
  - Fix usage with RMT and SMT
  - parse the /etc/products.d/*.prod files
* Wed Jun 19 2019 Sascha Grunert <sgrunert@suse.com>
- Update to 2.1.0 (bsc#1138731, bsc#1154247)
  - Fix function comments based on best practices from Effective Go
  - Interacting with SCC behind proxy and SMT
* Tue Dec 11 2018 sgrunert@suse.com
- Update to 2.0.0 (bsc#1119496)
  - Add command line interface
  - Add `ADDITIONAL_MODULES` capability to enable further extension
    modules during image build and run
  - Add documentation about how to build docker images on non SLE
    distributions
  - Improve documentation to clarify how container-suseconnect
    works in a Dockerfile
  - Improve error handling on non SLE hosts
  - Fix bug which makes container-suseconnect work on SLE15 based
    distributions
- Update build to use latest golang-packaging
- Added container-suseconnect-rpmlintrc
* Thu Mar  1 2018 jmassaguerpla@suse.com
- Remove gcc since the latest go versions already support s390x, ppc64le
  Remove 0001-Added-TLS-root-CA-certificates-for-SLE-11.patch: this
  was needed for gcc builds. (fix bsc#1083189)
* Wed Jul 27 2016 cbrauner@suse.de
- add aarch64 to supported gc architectures
* Wed Nov 11 2015 fcastelli@suse.com
- Update to version 1.1.0:
  - Improve logging
* Wed Nov 11 2015 fcastelli@suse.com
- Added 0001-Added-TLS-root-CA-certificates-for-SLE-11.patch to handle
  SLE11 certificates on non-x86 architectures
  work-around for bsc#953831
* Mon Jul 20 2015 fcastelli@suse.com
- Build using gcc on platforms where gc compiler is not available
* Thu Jun 18 2015 jmassaguerpla@suse.com
- Make SUSEConnect configuration file optional
  Update to v1.0.1
* Tue Jun 16 2015 jmassaguerpla@suse.com
- Update to v1.0.0
* Thu Jun 11 2015 fcastelli@suse.com
- Update to latest version from git
* Thu Jun  4 2015 fcastelli@suse.com
- Fixed building
* Thu Jun  4 2015 fcastelli@suse.com
- Update to latest version of container-suseconnect
* Wed Jun  3 2015 fcastelli@suse.com
- Fix libzypp requirement, it must be a runtime one
* Wed Jun  3 2015 fcastelli@suse.com
- Relax libzypp requirement to build the package also on SLE11SP3
* Fri May 29 2015 dmacvicar@suse.de
- initial package
